#
# spec file for package product-composer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if "%{?sle_version}" == "150600"
%define used_python python311
%else
%define used_python python3
%endif

Name:           product-composer
Version:        0.5.2
Release:        1.1
Summary:        Product Composer
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://github.com/openSUSE/product-composer
Source:         %name-%{version}.tar.xz
# Should become a build option
Patch1:         sle-15-defaults.patch
BuildRequires:  %{used_python}-pip
BuildRequires:  %{used_python}-poetry-core
BuildRequires:  %{used_python}-setuptools
BuildRequires:  %{used_python}-wheel
Requires:       %{used_python}-PyYAML
Requires:       %{used_python}-pydantic
Requires:       %{used_python}-rpm
Requires:       %{used_python}-zstandard
# build for signdummy
Requires:       build
Requires:       checkmedia
Requires:       createrepo_c
Requires:       inst-source-utils
Requires:       libsolv-tools
Requires:       mkisofs
Requires:       mksusecd
BuildArch:      noarch

%description
The new product builder for ALP family and beyond.
WARNING: please be aware that the code is still on the move and is
         likely to break with productcompose file syntax changes.

%prep
%setup -q -n %name-%version
%if "%{?sle_version}" == "150600"
%patch -P 1 -p1
%endif

%build
%if "%{?sle_version}" == "150600"
%python311_pyproject_wheel
%else
%python3_pyproject_wheel
%endif

%install
%if "%{?sle_version}" == "150600"
%python311_pyproject_install
%else
%python3_pyproject_install
%endif
mv %buildroot/usr/bin/productcomposer %buildroot%_bindir/product-composer

%files
%doc README.rst docs examples
%_bindir/product-composer
%if "%{?sle_version}" == "150600"
%{python311_sitelib}/*
%else
%{python3_sitelib}/*
%endif

%changelog
* Thu Jan 30 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.2
  Handle baseisos like meta packages
  This means we don't expect them deployed in the build host system
  anymore. Instead we search for them in the given repositories for
  the product and unpack the containment rpm.
  The wanted side effect of this is that products will get rebuild,
  when the baseiso has changed now.
* Wed Jan 29 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.1
  * use mksusecd instead of xorriso, fixes boot partition, requires root
* Tue Jan 28 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.5.0
  * New option to add generated rpm-md tree to a base image.
    Can be used to create an agama based offline installer image.
* Fri Jan 24 2025 Adrian Schröter <adrian@suse.de>
- update to version 0.4.21
  * Use generate_sbom from OBS server instance if available
* Mon Sep 30 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.20
  * fix logic of installcheck fatality
* Wed Sep 25 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.19
  * Avoid hanging installcheck with large output
* Mon Sep 23 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.18
  * Fix product name in SPDX SBOM files (was hardcoded to ALP)
  * Some more progress lines for logfile
* Mon Sep  2 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.17
  * abort_on_empty_updateinfo option added
  * allow to drop directory tree after iso generation
  * allow to enable iso generation by flavor
* Mon Jul 22 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.16
  * Crash fixes on incomplete iso spec or PkgSet substraction
* Wed Jul 17 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.15
  * avoid double export of -debug packages when using "all" option
* Tue Jul 16 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.14
  * added option to run installcheck
    => new dependency to libsolv-tools therefore
* Thu Jul 11 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.13
  * crash fix for "all available packages" option
* Mon Jul  8 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.12
  * fixed susedata generation (only a single language translation was generated)
  * Added option to include all available packages
* Wed Jun 26 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.11
  * canonized filenames (get rid of ::import prefixes)
* Wed Jun 26 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.10
  * support building on 15.6, using python311 stack (added sle-15-defaults.patch)
  * changing createrepo defaults for SLE 15 only
  * crash fix on incomplete generated groups by pkglistgen
* Wed Jun 26 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.9
  * Introduce "extension" product-type as alias for "module"
    Technical the same, but handled different in user accounting
  * fix for building without debug or source media
* Fri May 24 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.8
  * Support export of slsa.provenance files
  * Allow to override product directory per flavor
* Fri May 17 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.7
  * Support aborting on embargo updates in future
  * Clean updateinfo.xml from OBS internal elements
  * Add tagmedia for iso files to support checkmedia command
* Fri May 17 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.6
  * fixing signature creation for -Source and -Debug media
  * added option to allow to specify an updateinfo id prefix
* Thu May 16 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.5
  * generate .sha256 files for .iso files
* Thu Apr 11 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.4
  * supports also schema version 0.2 now
  * supports specifing add-on media product builds (versus OS)
  * supports overwriting package (from) information in updatinfo
* Wed Mar 27 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.3
  * Allow product builds without meta packages
  * improve disk-usage in susedata output
* Fri Mar  8 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.2
  * generate also diskusage data now (done by mls)
  * code cleanup
- add missing dependency to python-zstandard
* Thu Mar  7 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.1
  * write translations of package descriptions
* Wed Mar  6 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.4.0
  Replacement of susedata tool, first part
  - Add supportstatus
  - Add gpg trusted keys
  - switch to SHA512 checksum
  Missing:
  - diskusage data
  - package translations
* Fri Feb 23 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.4
  - support basic iso generation, not for bootable images yet
* Tue Feb  6 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.3
  - fixes incorrect data inside of repomd.xml
* Mon Feb  5 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.2
  * crash fixes
* Thu Jan 11 2024 Adrian Schröter <adrian@suse.de>
- update to version 0.3.1
  * Supporting new 0.1 schema with extended functionality
  * signature handling fix
  * refactoring and code cleanup and documentation updates
* Tue Dec  5 2023 Adrian Schröter <adrian@suse.de>
- update to version 0.2
  * Support .report file generation
* Mon Dec  4 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Set service to manual run: server side execution not permitted in
  products.
- Do not use python-single-spec magic, but use python3 directly
  (the main python version).
* Mon Dec  4 2023 Adrian Schröter <adrian@suse.de>
- roll version 0.1
  Kind of a beta version for ALP based products.
* Wed Nov 15 2023 Adrian Schröter <adrian@suse.de>
- initial package
